==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/pracovnipomery/f_vydejidentifikacnihomedia.php <==
<?php
/**
 * UTF-8
 * Roman.Szablatura 10.5.2016
 */
namespace Ron\RonPortal\Zamestnanci;

use Ron\Controls\ComboBox;
use Ron\DB\DBUtils;
use Ron\DBRecordField;
use Ron\FormField;
use Ron\RonPortal\PracovniPomer as PPomer;
use Ron\RonPortal\RonPortalForm;
use Ron\StringUtils;

require_once ('adsapp/ronportalform.php');

/**
 * Class IdentifikacniMedium
 * @package Ron\RonPortal\Zamestnanci
 */
class IdentifikacniMediumForm extends FormField
{
    private $url;

    function __construct($prava, $readOnly, $url)
    {
        parent::__construct();
        $this->readOnly = $readOnly;
        $this->fieldName = 'karta';
        $this->sqlFieldName = 'kodKarty';
        $this->maxLength = '30';
        $this->url = $url;
        $this->caption = \Ron\ronText('vybrane_medium');
    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        if($canEdit) {

            $combo = new ComboBox($this->fieldName);
            $sql =
                "SELECT  Karta.Kod, Karta.OznaceniMedia  FROM Karta LEFT JOIN S_ZpusobVyrazeniKarty ON (Karta.ZpusobVyrazeni = S_ZpusobVyrazeniKarty.Kod)" .
                "WHERE DatumPorizeni <= " . $database->timestampToString(time()) .
                "  AND (DatumVyrazeni >= " . $database->timestampToString(time()) . " OR DatumVyrazeni IS NULL)" .
                " AND NOT EXISTS(SELECT kodKarty FROM PrirazeniKarty WHERE kodKarty = Karta.kod AND datumPrideleni <= " . $database->timestampToString(time()) .
                "  AND (datumVraceni >= " . $database->timestampToString(time()) . " OR datumVraceni IS NULL))";

            $combo->emptyRow = \Ron\ronText('nevybrano');
            $combo->alwaysShowSelected = isset($value) && $value != '';
            $combo->className .= 'app_combo adsfilterforminput_popis';
            $combo->loadData($database, $sql, isset($_GET['kodkarty']) ? $_GET['kodkarty'] : '');
//            $combo->loadData($database, $sql, isset($value) ? $value : $_GET['kodkarty']);
            $combo->showCode = 1;
            $combo->htmlParams = 'data-ron-select2="karta_kod" onChange="window.location.href = &quot;' . $this->url  . '&formaction=new&amp;kodkarty=&quot;+this.value;"';
            $combo->render();

        } else {
            echo DBUtils::getSqlValue($database, "SELECT OznaceniMedia FROM Karta WHERE Kod = '" . $database->addSlashes($rowData[3]) . "'");
        }
    }

    /**
     * @param \Ron\DB\Database $database
     * @param string $tableName
     * @param int $insert
     * @param bool $utf8
     * @return null|DBRecordField
     */
    function createDBRecordField($database, $tableName, $insert, $utf8 = false)
    {
        $field = new DBRecordField($this->sqlFieldName, '', $this->readOnly, $this->maxLength);
        $field->setValue($_POST[$this->fieldName]);

        return $field;
    }
}

class VyrazenaIdentifikacniMediumForm extends FormField
{
    private $url;

    function __construct($prava, $readOnly,$url)
    {
        parent::__construct();
        $this->readOnly = $readOnly;
        $this->fieldName = 'karta';
        $this->sqlFieldName = 'kodKarty';
        $this->maxLength = '30';
        $this->url = $url;
        $this->caption = \Ron\ronText('vybrane_medium');
    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        if ($canEdit) {

            $combo = new ComboBox($this->fieldName);
            $sql =
                "SELECT  Karta.Kod, Karta.OznaceniMedia  FROM Karta LEFT JOIN S_ZpusobVyrazeniKarty ON (Karta.ZpusobVyrazeni = S_ZpusobVyrazeniKarty.Kod)" .
                "WHERE DatumPorizeni <= " . $database->timestampToString(time()) .
                "  AND DatumVyrazeni IS NOT NULL" .
                " AND NOT EXISTS(SELECT kodKarty FROM PrirazeniKarty WHERE kodKarty = Karta.kod AND datumPrideleni <= " . $database->timestampToString(time()) .
                "  AND (datumVraceni >= " . $database->timestampToString(time()) . " OR datumVraceni IS NULL))";

            $combo->emptyRow = \Ron\ronText('nevybrano');
            $combo->alwaysShowSelected = isset($value) && $value != '';
            $combo->className .= 'app_combo adsfilterforminput_popis';
            $combo->loadData($database, $sql, isset($_GET['kodkarty']) ? $_GET['kodkarty'] : '');
//            $combo->loadData($database, $sql, isset($value) ? $value : $_GET['kodkarty']);
            $combo->showCode = 1;
            $combo->htmlParams = 'data-ron-select2="karta_kod" onChange="window.location.href = &quot;' . $this->url . '&formaction=new&amp;kodkarty=&quot;+this.value;"';
            $combo->render();

        } else {
            echo DBUtils::getSqlValue($database, "SELECT OznaceniMedia FROM Karta WHERE Kod = '" . $database->addSlashes($rowData[3]) . "'");
        }
    }
}

class HistoriePrirazeniMediaForm extends FormField
{
    function __construct($options)
    {
        parent::__construct();
        $this->caption = \Ron\ronText('historie_prideleni');

    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        $sql =
            'SELECT PrirazeniKarty.datumPrideleni, PrirazeniKarty.datumVraceni, Osoba.Titul, Osoba.Prijmeni, Osoba.Jmeno ' . //0 - 4
            'FROM PrirazeniKarty, Osoba, Karta ' .
            "WHERE ( (PrirazeniKarty.KodKarty = '" . $_GET['kodkarty'] . "') and (Osoba.RC = PrirazeniKarty.RC) and (PrirazeniKarty.KodKarty = Karta.Kod) )";

        $cursor = $database->getSqlResult($sql);

        $result = '<table style="width:100%" >';
        $result .= '<td><strong>' . \Ron\ronText('datum_prideleni') . '</strong></td><td><strong>' . \Ron\ronText('datum_vraceni') . '</strong></td><td><strong>' . \Ron\ronText('Titul') .'</td><td><strong>'. \Ron\ronText('Prijmeni') .'</strong></td><td><strong>'. \Ron\ronText('Jmeno') . '</strong></td>';

        while ($row = $cursor->fetch()){
            $pocitadlo = 0;
            $result .= '<tr>';

            if($result){
                $result .= '';
            }
            foreach($row as $r){
                if($r) {
                    if($pocitadlo == 0 || $pocitadlo == 1){
                        $result .= '<td>' . StringUtils::format('date', $database->stringToTimestamp($r)) . '</td>';
                    } else {
                        $result .= '<td>' . $r . '</td>';
                    }
                } else {
                    $result .= '<td></td>';
                }
                $pocitadlo++;
            }
            $result .= '</tr>';
        }
        $result .= '</table>';
        echo $result;
    }
}

/**
 * Class VydejIDMediaForm
 * @package Ron\RonPortal
 */
class VydejIDMediaForm extends RonPortalForm
{
    /** @var  PPomer */
    private $pracPomer;
    private $kodKarty;
    private $datumPrideleni;

    /**
     * VydejIDMediaForm constructor.
     * @param \Ron\DB\Database $database
     * @param PPomer $pracPomer
     * @param string|null $kodKarty
     */
    function __construct($database, $pracPomer, $kodKarty = null, $datumPrideleni = null, $vyrazenaMedia)
    {
        parent::__construct($database);

        if($_GET['formaction'] == 'new') {
            $this->title = \Ron\ronText('prideleni_id_media');
        } elseif ($_GET['formaction'] == 'edit') {
            $this->title = \Ron\ronText('vraceni_id_media');
        }

        $this->pracPomer = $pracPomer;
        $this->kodKarty = $kodKarty;
        $this->datumPrideleni = $datumPrideleni;
        $this->htmlAction = '?menuid=zamestnanec&action=prirazenikarty&osoba='. $this->pracPomer->f_IdPP;
        $this->stornoAction = '?menuid=' . $_SESSION['Ron.Zamestnanci.Browser'];
        $this->dbLogSrcDescription = StringUtils::fromUTF8('Editace přidělení ID media');

        $this->sqlTableName = 'PrirazeniKarty';
        $this->sqlSelectPart = 'RC, osobniCislo, datumNastupu, kodKarty, datumPrideleni, datumVraceni';   //0 - 5

        //Zobrazeni sekce Osoby
        $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => 'Osoba']);
        $this->addFields([
            [FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_CAPTION_TEXT => 'Jmeno', FORM_FIELD_TEXT => $pracPomer->f_Jmeno],
            [FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_CAPTION_TEXT => 'Prijmeni', FORM_FIELD_TEXT => $pracPomer->f_Prijmeni],
            [FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_CAPTION_TEXT => 'Osobni_cislo', FORM_FIELD_TEXT => $pracPomer->f_OsobniCislo]
        ]);

        //Zobrazeni sekce Karty
        $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => \Ron\ronText('identifikacni_medium')]);

        $this->addField(new IdentifikacniMediumForm(null, true, $this->htmlAction /*. '&formaction=new'*/));

        $this->addField(new HistoriePrirazeniMediaForm($database));

        $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_DATE, FORM_FIELD_SQL_NAME => 'datumPrideleni',
            FORM_FIELD_NAME => 'datumPrideleni', FORM_FIELD_SQL_INDEX => 4, FORM_FIELD_CAPTION_TEXT => 'datum_prideleni', /*FORM_FIELD_PRIMARY => true,*/
            FORM_FIELD_EDIT => /*($_GET['formaction'] == 'edit') &&*/ 0]);

        if(!$this->isInsert()) {
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_DATE, FORM_FIELD_SQL_NAME => 'datumVraceni',
                FORM_FIELD_NAME => 'datumVraceni', FORM_FIELD_SQL_INDEX => 5, FORM_FIELD_CAPTION_TEXT => 'datum_vraceni',
                FORM_FIELD_EDIT => 1]);

            //Zobrazeni sekce vyřazení karty
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => \Ron\ronText('vyrazeni_media')]);
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_TEXT => '<a href="?menuid=zamestnanec&action=vyrazenimedia&formaction=edit&karta=' . $this->kodKarty . '">' .
            \Ron\ronText('vyradit_medium') . '</a>']);
        }

        if($vyrazenaMedia == 1) {
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => \Ron\ronText('vyrazena_blokovana_media')]);
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_TEXT => '<a href="?menuid=zamestnanec&action=obnovenimedia&formaction=edit">' . \Ron\ronText('obnovit_medium') . '</a>']);
        }
    }

    /**
     * @return string
     */
    function getWhereCondition()
    {
        $result = "RC = '" . $this->database->addSlashes($this->pracPomer->rc) . "'" .
            " AND OsobniCislo = '" . $this->database->addSlashes($this->pracPomer->osobniCislo) . "'" .
            ' AND DatumNastupu = ' . $this->database->timestampToString($this->pracPomer->datumNastupu) ;
        if ($this->kodKarty) {
            $result .= " AND kodKarty = '" . $this->database->addSlashes($this->kodKarty) . "'";
            $result .= " AND datumPrideleni = " . $this->database->timestampToString($this->datumPrideleni);
        }

        return $result;
    }

    function nacteniKoduMedia(){
        if (isset($_POST['karta'])) $karta = $_POST['karta'];
        else if (isset($_GET['karta'])) $karta = $_GET['karta'];
        else $karta = '';
        return $karta;
    }


    function showCommonFields()
    {
//        echo '<input type="hidden" name="RC" value="' . $this->pracPomer->f_RC . '" />';
//        echo '<input type="hidden" name="OsobniCislo" value="' . $this->pracPomer->f_OsobniCislo . '" />';
//        echo '<input type="hidden" name="DatumNastupu" value="' . $this->pracPomer->f_DatumNastupu . '" />';
        echo '<input type="hidden" name="osoba" value="' . $this->pracPomer->idPP . '" />';
        echo '<input type="hidden" name="kodkarty" value="'. $this->kodKarty . '" />';
        echo '<input type="hidden" name="datumprideleni" value="'. $this->datumPrideleni . '" />';
        echo '<input type="hidden" name="osoba" value="'. $_GET['osoba'] . '" />';

        parent::showCommonFields();
    }

    function createDBRecord()
    {
        $result =  parent::createDBRecord();

        $result->addField('RC', '', true, 15, $this->pracPomer->rc);
        $result->addField('OsobniCislo', '', true, 15, $this->pracPomer->osobniCislo);
        $result->addField('DatumNastupu', 'timestamp', true, 0, $this->pracPomer->datumNastupu);

        return $result;
    }

    function setDBRecord($rec)
    {
        parent::setDBRecord($rec);
        $rec->where = $this->getWhereCondition();
    }


    function beforeInsertRecord($rec)
    {
//        var_dump($rec);
        if($rec['kodKarty'] == ''){
            throw new \Exception(\Ron\ronText('nevybrano'));
        }
        if($rec['datumPrideleni'] == ''){
            throw new \Exception(\Ron\ronText('datum_prideleni_nesmi_byt_prazdne'));
        }

        $zadaneDatumPrideleni = $rec['datumPrideleni'];
        $jizVydaneVDatu = $this->database->stringToTimestamp(DBUtils::getSqlValue($this->database,
            "SELECT max (datumVraceni)
                  FROM PrirazeniKarty WHERE kodKarty = '" . $this->database->addSlashes($rec['kodKarty']) . "'"));
        if($zadaneDatumPrideleni <  $jizVydaneVDatu){
            throw new \Exception(\Ron\ronText('datum_obsazene'));
        }
        return parent::beforeInsertRecord($rec);
    }

    function beforeUpdateRecord($rec)
    {
        if($rec['datumVraceni'] == '' || ($rec['datumPrideleni'] > $rec['datumVraceni'])){
            throw new \Exception(\Ron\ronText('datum_vraceni_media'));
        }
        return parent::beforeUpdateRecord($rec);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/pracovnipomery/f_vydejidentifikacnihomedia.php <==
<?php
/**
 * UTF-8
 * Roman.Szablatura 10.5.2016
 */
namespace Ron\RonPortal\Zamestnanci;

use Ron\Controls\ComboBox;
use Ron\DB\DBUtils;
use Ron\DBRecordField;
use Ron\FormField;
use Ron\RonPortal\PracovniPomer as PPomer;
use Ron\RonPortal\RonPortalForm;
use Ron\StringUtils;

require_once ('adsapp/ronportalform.php');

/**
 * Class IdentifikacniMedium
 * @package Ron\RonPortal\Zamestnanci
 */
class IdentifikacniMediumForm extends FormField
{
    private $url;

    function __construct($prava, $readOnly, $url)
    {
        parent::__construct();
        $this->readOnly = $readOnly;
        $this->fieldName = 'karta';
        $this->sqlFieldName = 'kodKarty';
        $this->maxLength = '30';
        $this->url = $url;
        $this->caption = \Ron\ronText('vybrane_medium');
    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        if($canEdit) {

            $combo = new ComboBox($this->fieldName);
            $sql =
                "SELECT  Karta.Kod, Karta.OznaceniMedia  FROM Karta LEFT JOIN S_ZpusobVyrazeniKarty ON (Karta.ZpusobVyrazeni = S_ZpusobVyrazeniKarty.Kod)" .
                "WHERE DatumPorizeni <= " . $database->timestampToString(time()) .
                "  AND (DatumVyrazeni >= " . $database->timestampToString(time()) . " OR DatumVyrazeni IS NULL)" .
                " AND NOT EXISTS(SELECT kodKarty FROM PrirazeniKarty WHERE kodKarty = Karta.kod AND datumPrideleni <= " . $database->timestampToString(time()) .
                "  AND (datumVraceni >= " . $database->timestampToString(time()) . " OR datumVraceni IS NULL))";

            $combo->emptyRow = \Ron\ronText('nevybrano');
            $combo->alwaysShowSelected = isset($value) && $value != '';
            $combo->className .= 'app_combo adsfilterforminput_popis';
            $combo->loadData($database, $sql, isset($_GET['kodkarty']) ? $_GET['kodkarty'] : '');
//            $combo->loadData($database, $sql, isset($value) ? $value : $_GET['kodkarty']);
            $combo->showCode = 1;
            $combo->htmlParams = 'data-ron-select2="karta_kod" onChange="window.location.href = &quot;' . $this->url  . '&formaction=new&amp;kodkarty=&quot;+this.value;"';
            $combo->render();

        } else {
            echo DBUtils::getSqlValue($database, "SELECT OznaceniMedia FROM Karta WHERE Kod = '" . $database->addSlashes($rowData[3]) . "'");
        }
    }

    /**
     * @param \Ron\DB\Database $database
     * @param string $tableName
     * @param int $insert
     * @param bool $utf8
     * @return null|DBRecordField
     */
    function createDBRecordField($database, $tableName, $insert, $utf8 = false)
    {
        $field = new DBRecordField($this->sqlFieldName, '', $this->readOnly, $this->maxLength);
        $field->setValue($_POST[$this->fieldName]);

        return $field;
    }
}

class VyrazenaIdentifikacniMediumForm extends FormField
{
    private $url;

    function __construct($prava, $readOnly,$url)
    {
        parent::__construct();
        $this->readOnly = $readOnly;
        $this->fieldName = 'karta';
        $this->sqlFieldName = 'kodKarty';
        $this->maxLength = '30';
        $this->url = $url;
        $this->caption = \Ron\ronText('vybrane_medium');
    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        if ($canEdit) {

            $combo = new ComboBox($this->fieldName);
            $sql =
                "SELECT  Karta.Kod, Karta.OznaceniMedia  FROM Karta LEFT JOIN S_ZpusobVyrazeniKarty ON (Karta.ZpusobVyrazeni = S_ZpusobVyrazeniKarty.Kod)" .
                "WHERE DatumPorizeni <= " . $database->timestampToString(time()) .
                "  AND DatumVyrazeni IS NOT NULL" .
                " AND NOT EXISTS(SELECT kodKarty FROM PrirazeniKarty WHERE kodKarty = Karta.kod AND datumPrideleni <= " . $database->timestampToString(time()) .
                "  AND (datumVraceni >= " . $database->timestampToString(time()) . " OR datumVraceni IS NULL))";

            $combo->emptyRow = \Ron\ronText('nevybrano');
            $combo->alwaysShowSelected = isset($value) && $value != '';
            $combo->className .= 'app_combo adsfilterforminput_popis';
            $combo->loadData($database, $sql, isset($_GET['kodkarty']) ? $_GET['kodkarty'] : '');
//            $combo->loadData($database, $sql, isset($value) ? $value : $_GET['kodkarty']);
            $combo->showCode = 1;
            $combo->htmlParams = 'data-ron-select2="karta_kod" onChange="window.location.href = &quot;' . $this->url . '&formaction=new&amp;kodkarty=&quot;+this.value;"';
            $combo->render();

        } else {
            echo DBUtils::getSqlValue($database, "SELECT OznaceniMedia FROM Karta WHERE Kod = '" . $database->addSlashes($rowData[3]) . "'");
        }
    }
}

class HistoriePrirazeniMediaForm extends FormField
{
    function __construct($options)
    {
        parent::__construct();
        $this->caption = \Ron\ronText('historie_prideleni');

    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        $sql =
            'SELECT PrirazeniKarty.datumPrideleni, PrirazeniKarty.datumVraceni, Osoba.Titul, Osoba.Prijmeni, Osoba.Jmeno ' . //0 - 4
            'FROM PrirazeniKarty, Osoba, Karta ' .
            "WHERE ( (PrirazeniKarty.KodKarty = '" . $_GET['kodkarty'] . "') and (Osoba.RC = PrirazeniKarty.RC) and (PrirazeniKarty.KodKarty = Karta.Kod) )";

        $cursor = $database->getSqlResult($sql);

        $result = '<table style="width:100%" >';
        $result .= '<td><strong>' . \Ron\ronText('datum_prideleni') . '</strong></td><td><strong>' . \Ron\ronText('datum_vraceni') . '</strong></td><td><strong>' . \Ron\ronText('Titul') .'</td><td><strong>'. \Ron\ronText('Prijmeni') .'</strong></td><td><strong>'. \Ron\ronText('Jmeno') . '</strong></td>';

        while ($row = $cursor->fetch()){
            $pocitadlo = 0;
            $result .= '<tr>';

            if($result){
                $result .= '';
            }
            foreach($row as $r){
                if($r) {
                    if($pocitadlo == 0 || $pocitadlo == 1){
                        $result .= '<td>' . StringUtils::format('date', $database->stringToTimestamp($r)) . '</td>';
                    } else {
                        $result .= '<td>' . $r . '</td>';
                    }
                } else {
                    $result .= '<td></td>';
                }
                $pocitadlo++;
            }
            $result .= '</tr>';
        }
        $result .= '</table>';
        echo $result;
    }
}

/**
 * Class VydejIDMediaForm
 * @package Ron\RonPortal
 */
class VydejIDMediaForm extends RonPortalForm
{
    /** @var  PPomer */
    private $pracPomer;
    private $kodKarty;
    private $datumPrideleni;

    /**
     * VydejIDMediaForm constructor.
     * @param \Ron\DB\Database $database
     * @param PPomer $pracPomer
     * @param string|null $kodKarty
     */
    function __construct($database, $pracPomer, $kodKarty = null, $datumPrideleni = null, $vyrazenaMedia)
    {
        parent::__construct($database);

        if($_GET['formaction'] == 'new') {
            $this->title = \Ron\ronText('prideleni_id_media');
        } elseif ($_GET['formaction'] == 'edit') {
            $this->title = \Ron\ronText('vraceni_id_media');
        }

        $this->pracPomer = $pracPomer;
        $this->kodKarty = $kodKarty;
        $this->datumPrideleni = $datumPrideleni;
        $this->htmlAction = '?menuid=zamestnanec&action=prirazenikarty&osoba='. $this->pracPomer->f_IdPP;
        $this->stornoAction = '?menuid=' . $_SESSION['Ron.Zamestnanci.Browser'];
        $this->dbLogSrcDescription = StringUtils::fromUTF8('Editace přidělení ID media');

        $this->sqlTableName = 'PrirazeniKarty';
        $this->sqlSelectPart = 'RC, osobniCislo, datumNastupu, kodKarty, datumPrideleni, datumVraceni';   //0 - 5

        //Zobrazeni sekce Osoby
        $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => 'Osoba']);
        $this->addFields([
            [FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_CAPTION_TEXT => 'Jmeno', FORM_FIELD_TEXT => $pracPomer->jmeno],
            [FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_CAPTION_TEXT => 'Prijmeni', FORM_FIELD_TEXT => $pracPomer->prijmeni],
            [FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_CAPTION_TEXT => 'Osobni_cislo', FORM_FIELD_TEXT => $pracPomer->osobniCislo]
        ]);

        //Zobrazeni sekce Karty
        $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => \Ron\ronText('identifikacni_medium')]);

        $this->addField(new IdentifikacniMediumForm(null, true, $this->htmlAction /*. '&formaction=new'*/));

        $this->addField(new HistoriePrirazeniMediaForm($database));

        $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_DATE, FORM_FIELD_SQL_NAME => 'datumPrideleni',
            FORM_FIELD_NAME => 'datumPrideleni', FORM_FIELD_SQL_INDEX => 4, FORM_FIELD_CAPTION_TEXT => 'datum_prideleni', /*FORM_FIELD_PRIMARY => true,*/
            FORM_FIELD_EDIT => /*($_GET['formaction'] == 'edit') &&*/ 0]);

        if(!$this->isInsert()) {
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_DATE, FORM_FIELD_SQL_NAME => 'datumVraceni',
                FORM_FIELD_NAME => 'datumVraceni', FORM_FIELD_SQL_INDEX => 5, FORM_FIELD_CAPTION_TEXT => 'datum_vraceni',
                FORM_FIELD_EDIT => 1]);

            //Zobrazeni sekce vyřazení karty
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => \Ron\ronText('vyrazeni_media')]);
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_TEXT => '<a href="?menuid=zamestnanec&action=vyrazenimedia&formaction=edit&karta=' . $this->kodKarty . '">' .
            \Ron\ronText('vyradit_medium') . '</a>']);
        }

        if($vyrazenaMedia == 1) {
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_SECTION, FORM_FIELD_CAPTION_TEXT => \Ron\ronText('vyrazena_blokovana_media')]);
            $this->addField([FORM_FIELD_TYPE => FORM_FIELD_TYPE_TEXT, FORM_FIELD_TEXT => '<a href="?menuid=zamestnanec&action=obnovenimedia&formaction=edit">' . \Ron\ronText('obnovit_medium') . '</a>']);
        }
    }

    /**
     * @return string
     */
    function getWhereCondition()
    {
        $result = "RC = '" . $this->database->addSlashes($this->pracPomer->rc) . "'" .
            " AND OsobniCislo = '" . $this->database->addSlashes($this->pracPomer->osobniCislo) . "'" .
            ' AND DatumNastupu = ' . $this->database->timestampToString($this->pracPomer->datumNastupu) ;
        if ($this->kodKarty) {
            $result .= " AND kodKarty = '" . $this->database->addSlashes($this->kodKarty) . "'";
            $result .= " AND datumPrideleni = " . $this->database->timestampToString($this->datumPrideleni);
        }

        return $result;
    }

    function nacteniKoduMedia(){
        if (isset($_POST['karta'])) $karta = $_POST['karta'];
        else if (isset($_GET['karta'])) $karta = $_GET['karta'];
        else $karta = '';
        return $karta;
    }


    function showCommonFields()
    {
//        echo '<input type="hidden" name="RC" value="' . $this->pracPomer->f_RC . '" />';
//        echo '<input type="hidden" name="OsobniCislo" value="' . $this->pracPomer->f_OsobniCislo . '" />';
//        echo '<input type="hidden" name="DatumNastupu" value="' . $this->pracPomer->f_DatumNastupu . '" />';
        echo '<input type="hidden" name="osoba" value="' . $this->pracPomer->idPP . '" />';
        echo '<input type="hidden" name="kodkarty" value="'. $this->kodKarty . '" />';
        echo '<input type="hidden" name="datumprideleni" value="'. $this->datumPrideleni . '" />';
        echo '<input type="hidden" name="osoba" value="'. $_GET['osoba'] . '" />';

        parent::showCommonFields();
    }

    function createDBRecord()
    {
        $result =  parent::createDBRecord();

        $result->addField('RC', '', true, 15, $this->pracPomer->rc);
        $result->addField('OsobniCislo', '', true, 15, $this->pracPomer->osobniCislo);
        $result->addField('DatumNastupu', 'timestamp', true, 0, $this->pracPomer->datumNastupu);

        return $result;
    }

    function setDBRecord($rec)
    {
        parent::setDBRecord($rec);
        $rec->where = $this->getWhereCondition();
    }


    function beforeInsertRecord($rec)
    {
//        var_dump($rec);
        if($rec['kodKarty'] == ''){
            throw new \Exception(\Ron\ronText('nevybrano'));
        }
        if($rec['datumPrideleni'] == ''){
            throw new \Exception(\Ron\ronText('datum_prideleni_nesmi_byt_prazdne'));
        }

        $zadaneDatumPrideleni = $rec['datumPrideleni'];
        $jizVydaneVDatu = $this->database->stringToTimestamp(DBUtils::getSqlValue($this->database,
            "SELECT max (datumVraceni)
                  FROM PrirazeniKarty WHERE kodKarty = '" . $this->database->addSlashes($rec['kodKarty']) . "'"));
        if($zadaneDatumPrideleni <  $jizVydaneVDatu){
            throw new \Exception(\Ron\ronText('datum_obsazene'));
        }
        return parent::beforeInsertRecord($rec);
    }

    function beforeUpdateRecord($rec)
    {
        if($rec['datumVraceni'] == '' || ($rec['datumPrideleni'] > $rec['datumVraceni'])){
            throw new \Exception(\Ron\ronText('datum_vraceni_media'));
        }
        return parent::beforeUpdateRecord($rec);
    }
}
